@@ -1,4 +1,4 @@
-package Dancer2::Plugin::DBIx::Class 1.05;
+package Dancer2::Plugin::DBIx::Class 1.06;
 use Modern::Perl;
 use Carp;
 use Class::C3::Componentised;
@@ -20,7 +20,7 @@ sub BUILD {
          my $export_builder
             = Dancer2::Plugin::DBIx::Class::ExportBuilder->new(
             map { $_ => $config->{default}->{$_} }
-               qw(schema_class dsn export_prefix) );
+               qw(schema_class dsn user password export_prefix) );
          my %new_keywords = $export_builder->exports;
          foreach
             my $dsl_keyword ( keys %{ Dancer2::Core::DSL->dsl_keywords } ) {
@@ -35,7 +35,7 @@ sub BUILD {
       my $export_builder
          = Dancer2::Plugin::DBIx::Class::ExportBuilder->new(
          map { $_ => $config->{$schema}->{$_} }
-            qw(schema_class dsn export_prefix) );
+            qw(schema_class dsn user password export_prefix) );
       my %new_keywords = $export_builder->exports;
       foreach my $dsl_keyword ( keys %{ Dancer2::Core::DSL->dsl_keywords } ) {
          delete $new_keywords{$dsl_keyword};
@@ -142,7 +142,7 @@ Dancer2::Plugin::DBIx::Class - syntactic sugar for DBIx::Class in Dancer2, optio
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 SYNOPSIS
 
